;; Generated package description from dape.el  -*- no-byte-compile: t -*-
(define-package "dape" "0.5.0" "Debug Adapter Protocol for Emacs" '((emacs "29.1") (jsonrpc "1.0.21")) :commit "b7fce202149b6cbbab78818d5448d6647a6b7e5e" :maintainer '("Daniel Pettersson" . "daniel@dpettersson.net") :url "https://github.com/svaante/dape")
